Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(704)

Unified Diff: services/preferences/tracked/pref_hash_filter.h

Issue 2745563005: Pref service: add support for tracked prefs. (Closed)
Patch Set: deflake tests Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/preferences/tracked/pref_hash_filter.h
diff --git a/services/preferences/tracked/pref_hash_filter.h b/services/preferences/tracked/pref_hash_filter.h
index 7cc2fac889350e8bd0b6c9b8a904dbdfe820a8f6..4c3cdaa4996a46f9486cfc41c1a4aee7792370b5 100644
--- a/services/preferences/tracked/pref_hash_filter.h
+++ b/services/preferences/tracked/pref_hash_filter.h
@@ -52,8 +52,8 @@ class PrefHashFilter : public InterceptablePrefFilter {
// Constructs a PrefHashFilter tracking the specified |tracked_preferences|
// using |pref_hash_store| to check/store hashes. An optional |delegate| is
// notified of the status of each preference as it is checked.
// If |on_reset_on_load| is provided, it will be invoked if a reset occurs in
// FilterOnLoad.
// |reporting_ids_count| is the count of all possible IDs (possibly greater
// than |tracked_preferences.size()|). If |report_super_mac_validity| is true,
// the state of the super MAC will be reported via UMA during
@@ -64,7 +64,7 @@ class PrefHashFilter : public InterceptablePrefFilter {
StoreContentsPair external_validation_hash_store_pair_,
const std::vector<prefs::mojom::TrackedPreferenceMetadataPtr>&
tracked_preferences,
- const base::Closure& on_reset_on_load,
+ prefs::mojom::ResetOnLoadObserverPtr reset_on_load_observer,
prefs::mojom::TrackedPreferenceValidationDelegate* delegate,
size_t reporting_ids_count,
bool report_super_mac_validity);
@@ -139,8 +139,8 @@ class PrefHashFilter : public InterceptablePrefFilter {
// Will be null if the platform does not support external validation.
const base::Optional<StoreContentsPair> external_validation_hash_store_pair_;
- // Invoked if a reset occurs in a call to FilterOnLoad.
- base::Closure on_reset_on_load_;
+ // Notified if a reset occurs in a call to FilterOnLoad.
+ prefs::mojom::ResetOnLoadObserverPtr reset_on_load_observer_;
TrackedPreferencesMap tracked_paths_;

Powered by Google App Engine
@@ -52,8 +52,8 @@ class PrefHashFilter : public InterceptablePrefFilter {
// using |pref_hash_store| to check/store hashes. An optional |delegate| is
// notified of the status of each preference as it is checked.
- // If |on_reset_on_load| is provided, it will be invoked if a reset occurs in
- // FilterOnLoad.
+ // If |reset_on_load_observer| is provided, it will be notified if a reset
+ // occurs in FilterOnLoad.
// |reporting_ids_count| is the count of all possible IDs (possibly greater
// than |tracked_preferences.size()|). If |report_super_mac_validity| is true,
This is Rietveld 408576698